---
title: Parareal
subtitle: a library for parallel-in-time computations in Python
---
[![Entangled badge](https://img.shields.io/badge/entangled-Use%20the%20source!-%2300aeff)](https://entangled.github.io/)

This package runs the parareal algorithm on a black-box simulator. Parallelisation is managed through Dask.

# License
Apache 2, see `LICENSE`.

